zms._confmanager.ConfDict

Package zms :: Module _confmanager :: Class ConfDict |
[frames] | no frames]

# Class ConfDict

    object --+
             |
            ConfDict

Instance Methods
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Methods
get(cls) |
forName(cls, name) |

Class Variables
| __confdict__ = `None`

Properties
Inherited from `object`: `__class__`